==> tuia-commercial-center-api-0.0.4-20190718.040007-11-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/story/user/req/StoryUserReq.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.story.user.req;

import java.io.Serializable;

/**
 * StoryUserReq
 *
 * @author huangruodan
 * @date 2019/5/21
 */
public class StoryUserReq implements Serializable {
    private static final long serialVersionUID = 1399783320437030080L;

    /**
     * 设备id
     */
    private String deviceId;

    /**
     * 媒体id
     */
    private Long appId;

    /**
     * 用户id
     */
    private Long consumerId;

    /**
     * 活动id
     */
    private Long activityId;

    /**
     * 广告位id
     */
    private Long slotId;

    /**
     * ip
     */
    private String ip;

    public StoryUserReq(String deviceId, Long appId, Long consumerId) {
        this.deviceId = deviceId;
        this.appId = appId;
        this.consumerId = consumerId;
    }

    public StoryUserReq() {
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    @Override
    public String toString() {
        return "StoryUserReq{" +
                "deviceId='" + deviceId + '\'' +
                ", appId=" + appId +
                ", consumerId=" + consumerId +
                '}';
    }
}

==> tuia-commercial-center-api-0.0.6-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/story/user/req/StoryUserReq.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.story.user.req;

import java.io.Serializable;

/**
 * StoryUserReq
 *
 * @author huangruodan
 * @date 2019/5/21
 */
public class StoryUserReq implements Serializable {
    private static final long serialVersionUID = 1399783320437030080L;

    /**
     * 设备id
     */
    private String deviceId;

    /**
     * 媒体id
     */
    private Long appId;

    /**
     * 用户id
     */
    private Long consumerId;

    /**
     * 活动id
     */
    private Long activityId;

    /**
     * 广告位id
     */
    private Long slotId;

    /**
     * ip
     */
    private String ip;

    /**
     * 是否对任务进行排序
     */
    private Boolean isOrderMission;

    /**
     * 故事完整性版本
     */
    private String version;

    public StoryUserReq(String deviceId, Long appId, Long consumerId) {
        this.deviceId = deviceId;
        this.appId = appId;
        this.consumerId = consumerId;
    }

    public StoryUserReq() {
    }

    public Boolean getOrderMission() {
        return isOrderMission;
    }

    public void setOrderMission(Boolean orderMission) {
        isOrderMission = orderMission;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getActivityId() {
        return activityId;
    }

    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    @Override
    public String toString() {
        return "StoryUserReq{" +
                "deviceId='" + deviceId + '\'' +
                ", appId=" + appId +
                ", consumerId=" + consumerId +
                '}';
    }
}
